pub enum Value {
Null,
Bool(bool),
Number(Number),
String(String),
Array(Vec<Value>),
Object(Map),
}Expand description
A self-describing JSON value.
Variants
Null
null
Bool(bool)
true / false
Number(Number)
Number (lossless through i128 / u128, see Number).
String(String)
string
Array(Vec<Value>)
array
Object(Map)
object (insertion-ordered Map)
Implementations
Sourceimpl Value
impl Value
Sourcepub fn as_array_mut(&mut self) -> Option<&mut Vec<Value>>
pub fn as_array_mut(&mut self) -> Option<&mut Vec<Value>>
The mutable array reference, if this is an array.
Sourcepub fn as_object_mut(&mut self) -> Option<&mut Map>
pub fn as_object_mut(&mut self) -> Option<&mut Map>
The mutable object reference, if this is an object.
Sourcepub fn get_mut(&mut self, key: &str) -> Option<&mut Value>
pub fn get_mut(&mut self, key: &str) -> Option<&mut Value>
Get a value by key, mutable (objects only).
Sourcepub fn pointer(&self, pointer: &str) -> Option<&Value>
pub fn pointer(&self, pointer: &str) -> Option<&Value>
Locate a value by RFC 6901 JSON Pointer.
/a/b/0 descends into a -> b -> first array element; ~0 / ~1
escape ~ and /. The empty pointer returns self.
Sourcepub fn into_object(self) -> Option<Map>
pub fn into_object(self) -> Option<Map>
Consume self into a Map (if object).
Sourcepub fn into_array(self) -> Option<Vec<Value>>
pub fn into_array(self) -> Option<Vec<Value>>
Consume self into a Vec (if array).